@@ -1,10 +1,10 @@
-context("regr_btgpllm")
 
 test_that("regr_btgpllm", {
+  skip("not runnable in parallel")
+  # due to https://github.com/cran/tgp/blob/689168f5e43941e2808c36bc43603329641028db/R/tgp.postprocess.R#L75 # nocov
   requirePackagesOrSkip("tgp", default.method = "load")
 
   parset.list = list(
-    list(),
     list(meanfn = "linear", bprior = "bflat", corr = "expsep")
   )
 
@@ -26,9 +26,9 @@ test_that("regr_btgpllm", {
     parset = parset.list[[i]]
     pars = list(X = train, Z = y, verb = 0, basemax = n.num, pred.n = FALSE)
     pars = c(pars, parset)
-    set.seed(getOption("mlr.debug.seed"))
     m = do.call(tgp::btgpllm, pars)
     old.predicts.list[[i]] = predict(m, XX = test, pred.n = FALSE)$ZZ.km
   }
-  testSimpleParsets("regr.btgpllm", regr.df[, c(2:5, 14)], regr.target, inds, old.predicts.list, parset.list)
+  testSimpleParsets("regr.btgpllm", regr.df[, c(2:5, 14)], regr.target, inds,
+    old.predicts.list, parset.list)
 })
